@@ -30,6 +30,7 @@
 #endif
 
 #include <X11/Xatom.h>
+#include <glade/glade.h>
 #include "callbacks.h"
 #include "gok-scanner.h"
 #include "gok-input.h"
@@ -346,7 +347,7 @@ on_radiobuttonTypeValuator_toggled (GtkToggleButton *togglebutton,
 
 
 void
-on_combo_entry16_changed               (GtkEditable     *editable,
+on_entryActionName_changed               (GtkEditable     *editable,
                                         gpointer         user_data)
 {
 	gok_page_actions_action_changed ((GtkEditable*)editable);
@@ -793,6 +794,12 @@ on_entrySoundName_changed              (GtkEditable     *editable,
 	gok_page_feedbacks_entry_soundname_changed();
 }
 
+void
+on_SpeakLabelCheckButton_toggled (GtkToggleButton *button)
+{
+	gok_page_feedbacks_check_speech_toggled (button);
+}
+
 void
 on_notebook2_switch_page               (GtkNotebook     *notebook,
                                         GtkNotebookPage *page,
@@ -879,6 +886,115 @@ on_key_averaging_button_toggled        (GtkToggleButton *togglebutton,
 	gok_page_actions_pointer_keyaverage (gtk_toggle_button_get_active (togglebutton));
 }
 
+void
+on_ValuatorSensitivityScale_value_changed (GtkRange *range,
+					   gpointer  user_data)
+{
+	gok_data_set_valuator_sensitivity (gtk_range_get_value (range));
+}
+
+void
+on_dock_checkbutton_toggled (GtkToggleButton *button, 
+			     gpointer user_data)
+{
+	GtkWidget *dockbottom, *docktop;
+	GokDockType dock_type;
+	gboolean is_dock = gtk_toggle_button_get_active (button);
+	GladeXML *xml = gok_settingsdialog_get_xml ();
+	dockbottom = glade_xml_get_widget (xml, "DockBottomRadiobutton");
+	docktop = glade_xml_get_widget (xml, "DockTopRadiobutton");
+
+	gtk_widget_set_sensitive (docktop, is_dock);
+	gtk_widget_set_sensitive (dockbottom, is_dock);
+
+	if (is_dock)
+	{
+		if (docktop &&  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (docktop)))
+		{
+			dock_type = GOK_DOCK_TOP;
+		}
+		else
+		{
+			dock_type = GOK_DOCK_BOTTOM;
+		}
+	}
+	else
+	{
+		dock_type = GOK_DOCK_NONE;
+	}
+	gok_data_set_dock_type (dock_type);
+}
+
+void
+on_fill_checkbutton_toggled (GtkToggleButton *button, 
+			     gpointer user_data)
+{
+	gok_data_set_expand (gtk_toggle_button_get_active (button));
+}
+
+void
+on_dock_top_radiobutton_toggled (GtkToggleButton *button, 
+				 gpointer user_data)
+{
+	if (gtk_toggle_button_get_active (button))
+		gok_data_set_dock_type (GOK_DOCK_TOP);
+}
+
+void
+on_dock_bottom_radiobutton_toggled (GtkToggleButton *button, 
+				    gpointer user_data)
+{
+	if (gtk_toggle_button_get_active (button))
+		gok_data_set_dock_type (GOK_DOCK_BOTTOM);
+}
+
+void
+on_aux_keyboard_dir_entry_changed (GtkEntry *entry,
+				   gpointer user_data)
+{
+	gok_data_set_aux_keyboard_directory (gtk_entry_get_text (entry));
+}
+
+
+void
+on_xkb_compose_keyboard_radiobutton_toggled (GtkToggleButton *button, 
+					     gpointer user_data)
+{
+	if (gtk_toggle_button_get_active (button))
+		gok_data_set_compose_keyboard_type (GOK_COMPOSE_XKB);
+}
+
+void
+on_alpha_compose_keyboard_radiobutton_toggled (GtkToggleButton *button, 
+					       gpointer user_data)
+{
+	if (gtk_toggle_button_get_active (button))
+		gok_data_set_compose_keyboard_type (GOK_COMPOSE_ALPHA);
+}
+
+void
+on_freq_compose_keyboard_radiobutton_toggled (GtkToggleButton *button, 
+					      gpointer user_data)
+{
+	if (gtk_toggle_button_get_active (button))
+		gok_data_set_compose_keyboard_type (GOK_COMPOSE_ALPHAFREQ);
+}
+
+void
+on_file_compose_keyboard_radiobutton_toggled (GtkToggleButton *button, 
+					      gpointer user_data)
+{
+	if (gtk_toggle_button_get_active (button))
+		gok_data_set_compose_keyboard_type (GOK_COMPOSE_CUSTOM);
+}
+
+void
+on_compose_keyboard_file_entry_changed (GtkEditable *editable, 
+					gpointer user_data)
+{
+	gok_data_set_custom_compose_filename (
+		gtk_editable_get_chars (editable, 0, -1));
+}
 
 void
 on_core_pointer_button_toggled         (GtkToggleButton *togglebutton,
@@ -913,3 +1029,43 @@ on_checkExtraWordList_toggled          (GtkToggleButton *togglebutton,
 	gok_page_wordcomplete_toggle_wordlist (gtk_toggle_button_get_active (togglebutton));
 }
 
+void
+on_buttonHelp_clicked                  (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	on_button_help (button, user_data);
+}
+
+
+void
+on_buttonApply_clicked                   (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	on_button_try (button, user_data);
+}
+
+
+void
+on_buttonRevert_clicked                (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	on_button_revert (button, user_data);
+}
+
+
+void
+on_buttonCancel_clicked                (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	on_button_cancel (button, user_data);
+}
+
+
+void
+on_buttonOK_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	on_button_ok (button, user_data);
+}
+
+
