@@ -32,7 +32,8 @@
 #include "main.h"
 
 /* Private functions */
-void gok_data_set_name_accessmethod_internal (char* Name);
+static void gok_data_set_name_accessmethod_internal (char* Name);
+static const GokComposeType gok_data_compose_type_from_string (const gchar *s);
 
 /* pointer to the first GokData setting */
 static GokSetting* m_pSettingFirst;
@@ -65,8 +66,10 @@ static gboolean m_bDriveCorePointer = FALSE;
 static gboolean m_bExpandWindow;
 static gboolean m_bUseXkbKbd;
 static gboolean m_bUseAuxDicts = FALSE;
-static const gchar *m_AuxDicts = NULL;
+static gdouble m_ValuatorSensitivity = 0.25;
+static gchar *m_AuxDicts = NULL;
 static GokDockType m_eDockType;
+static GokComposeType compose_keyboard_type;
 
 /* This GConfClient will be shared by all gconf_client
  * calls in this file.
@@ -230,6 +233,9 @@ gboolean gok_data_read_settings (void)
 	gok_gconf_get_bool (gconf_client, GOK_GCONF_USE_AUX_DICTS, 
 			         &m_bUseAuxDicts);
 
+ 	gok_gconf_get_double (gconf_client, GOK_GCONF_VALUATOR_SENSITIVITY,
+                                 &m_ValuatorSensitivity);
+
         gok_gconf_get_string (gconf_client, GOK_GCONF_AUX_DICTS, 
 			         &m_AuxDicts);
 
@@ -238,6 +244,11 @@ gboolean gok_data_read_settings (void)
         m_eDockType = gok_data_dock_type_from_string (a_gchar);
 	g_free (a_gchar);
 
+	gok_gconf_get_string (gconf_client, GOK_GCONF_COMPOSE_KBD_TYPE,
+			      &a_gchar);
+        compose_keyboard_type = gok_data_compose_type_from_string (a_gchar);
+	g_free (a_gchar);
+
 	/* Read in settings for individual access methods */
 	access_method_dirs
 	    = gconf_client_all_dirs (gconf_client,
@@ -700,7 +711,7 @@ gboolean gok_data_get_use_xkb_kbd ()
 void gok_data_set_use_xkb_kbd (gboolean val)
 {
 	m_bUseXkbKbd = val;
-	gok_gconf_set_int (gconf_client, GOK_GCONF_USE_XKB_KBD,
+	gok_gconf_set_bool (gconf_client, GOK_GCONF_USE_XKB_KBD,
 				m_bUseXkbKbd);
 	m_bSettingsChanged = TRUE;
 }
@@ -728,12 +739,15 @@ void gok_data_set_dock_type (GokDockType val)
 	switch (val) {
 	case GOK_DOCK_TOP:
 	  typestring = "top";
+	  gok_main_set_wm_dock (TRUE);
 	  break;
 	case GOK_DOCK_BOTTOM:
 	  typestring = "bottom";
+	  gok_main_set_wm_dock (TRUE);
 	  break;
 	default:
 	  typestring = "";
+	  gok_main_set_wm_dock (FALSE);
 	  break;
 	}
 	gok_gconf_set_string (gconf_client, GOK_GCONF_DOCK_TYPE,
@@ -855,7 +869,8 @@ void gok_data_set_keysize_priority (gboolean bFlag)
  *
  * This function does not write to GConf it only copies the string
  */
-void gok_data_set_name_accessmethod_internal (char* Name)
+static void 
+gok_data_set_name_accessmethod_internal (char* Name)
 {
 	if (strcmp (Name, NameAccessMethod) == 0)
 	{
@@ -1044,9 +1059,16 @@ gboolean gok_data_get_expand ()
  */
 void gok_data_set_expand (gboolean bTrueFalse)
 {
+	GokKeyboard *kbd = gok_main_get_current_keyboard ();
 	m_bExpandWindow= bTrueFalse;
 	gok_gconf_set_bool (gconf_client, GOK_GCONF_EXPAND,
 			    m_bExpandWindow);
+	if (kbd)
+	{
+		gok_keyboard_display (kbd,
+				      kbd,
+				      gok_main_get_main_window (), TRUE);
+	}
 	m_bSettingsChanged = TRUE;
 }
 
@@ -1188,16 +1210,91 @@ gboolean gok_data_restore_setting (GokSetting* pSetting)
 gdouble
 gok_data_get_valuator_sensitivity (void)
 {
-	/* TODO: implement in gconf */
-	return 1.0;
+	return m_ValuatorSensitivity;
 }
 
 void 
 gok_data_set_valuator_sensitivity (gdouble multiplier)
 {
-	/* TODO: implement in gconf */
+	m_ValuatorSensitivity = multiplier;
+	gok_gconf_set_double (gconf_client, GOK_GCONF_VALUATOR_SENSITIVITY,
+			      m_ValuatorSensitivity);
+	m_bSettingsChanged = TRUE;
 }
 
+const gchar*
+gok_data_compose_keyboard_type_string (GokComposeType type)
+{
+    switch (type)
+    {
+	case GOK_COMPOSE_XKB:
+	    return "xkb";
+	case GOK_COMPOSE_ALPHA:
+	    return "alpha";
+	case GOK_COMPOSE_ALPHAFREQ:
+	    return "alpha-freq";
+	case GOK_COMPOSE_CUSTOM:
+	    return "custom";
+	case GOK_COMPOSE_DEFAULT:
+	default:
+	    return "default";
+    }
+}
+
+static const GokComposeType
+gok_data_compose_type_from_string (const gchar *s)
+{
+	if (!strcmp ("xkb", s)) return GOK_COMPOSE_XKB;
+	else if (!strcmp ("alpha", s)) return GOK_COMPOSE_ALPHA;
+	else if (!strcmp ("alpha-freq", s)) return GOK_COMPOSE_ALPHAFREQ;
+	else if (!strcmp ("custom", s)) return GOK_COMPOSE_CUSTOM;
+	else return GOK_COMPOSE_DEFAULT;
+}
+
+GokComposeType 
+gok_data_get_compose_keyboard_type (void)
+{
+    return compose_keyboard_type;
+}
+
+void 
+gok_data_set_compose_keyboard_type (GokComposeType type)
+{
+    compose_keyboard_type = type;
+    gok_gconf_set_string (gconf_client, GOK_GCONF_COMPOSE_KBD_TYPE,
+			  gok_data_compose_keyboard_type_string (type));
+    gok_data_set_use_xkb_kbd (type == GOK_COMPOSE_XKB);    
+}
+
+gchar *
+gok_data_get_custom_compose_filename (void)
+{
+	gchar *s;
+	return (gok_gconf_get_string (gconf_client, GOK_GCONF_CUSTOM_COMPOSE_FILENAME,
+				     &s) ? s : NULL);
+}
+
+void 
+gok_data_set_custom_compose_filename (const gchar *filename)
+{
+	gok_gconf_set_string (gconf_client, GOK_GCONF_CUSTOM_COMPOSE_FILENAME, filename);
+}
+
+gchar *
+gok_data_get_aux_keyboard_directory (void)
+{
+	gchar *s;
+	return (gok_gconf_get_string (gconf_client, GOK_GCONF_AUX_KEYBOARD_DIRECTORY,
+				     &s) ? s : NULL);
+}
+
+void 
+gok_data_set_aux_keyboard_directory (const gchar *dirname)
+{
+	gok_gconf_set_string (gconf_client, GOK_GCONF_AUX_KEYBOARD_DIRECTORY, dirname);
+}
+
+
 gint
 gok_data_get_repeat_rate (void)
 {
@@ -1215,10 +1312,10 @@ gok_data_set_repeat_rate (gint rate)
 /* 
  * gok_data_get_aux_dictionaries:
  *
- * Returns a constant string which specifies a semicolon-delimited
+ * Returns a string which specifies a semicolon-delimited
  * list of fully-qualified paths to word lists.
  */
-const gchar* 
+gchar* 
 gok_data_get_aux_dictionaries (void)
 {
 	return m_AuxDicts;
@@ -1229,7 +1326,7 @@ gok_data_get_aux_dictionaries (void)
  *
  */
 void
-gok_data_set_aux_dictionaries (const gchar *dictionaries)
+gok_data_set_aux_dictionaries (gchar *dictionaries)
 {
 	m_AuxDicts = dictionaries;
 	gok_gconf_set_string (gconf_client, GOK_GCONF_AUX_DICTS,
