@@ -70,6 +70,14 @@ typedef enum {
   GOK_DOCK_TOP
 } GokDockType;
   
+typedef enum {
+  GOK_COMPOSE_DEFAULT,
+  GOK_COMPOSE_XKB,
+  GOK_COMPOSE_ALPHA,
+  GOK_COMPOSE_ALPHAFREQ,
+  GOK_COMPOSE_CUSTOM
+} GokComposeType;
+  
 void gok_data_initialize (void);
 GokSetting* gok_data_construct_setting (void);
 gboolean gok_data_read_settings (void);
@@ -119,10 +127,16 @@ void gok_data_set_dock_type (GokDockType dock_type);
 gint gok_data_get_repeat_rate (void);
 void gok_data_set_repeat_rate (gint rate);
 GConfClient* gok_data_get_gconf_client (void);
-const gchar* gok_data_get_aux_dictionaries (void);
-void gok_data_set_aux_dictionaries (const gchar *dictionaries);
+gchar* gok_data_get_aux_dictionaries (void);
+void gok_data_set_aux_dictionaries (gchar *dictionaries);
 gboolean gok_data_get_use_aux_dictionaries (void);
 void gok_data_set_use_aux_dictionaries (gboolean use_aux);
+GokComposeType gok_data_get_compose_keyboard_type (void);
+void gok_data_set_compose_keyboard_type (GokComposeType type);
+gchar *gok_data_get_custom_compose_filename (void);
+void gok_data_set_custom_compose_filename (const gchar *filename);
+gchar *gok_data_get_aux_keyboard_directory (void);
+void gok_data_set_aux_keyboard_directory (const gchar *filename);
 
 #ifdef __cplusplus
 }
