@@ -31,6 +31,8 @@
 #include "gok-gconf.h"
 #include "gok-gconf-keys.h"
 #include "gok-sound.h"
+#include "gok-speech.h"
+#include "gok-key.h"
 
 /* Pointer to the first feedback in the list of feedback */
 static GokFeedback* m_pFeedbackFirst;
@@ -44,6 +46,8 @@ static gboolean m_bFlashState;
 /* key that is currently selected (this may be different from key highlighted) */
 static GokKey* m_pKeySelected;
 
+static gchar*  m_keyLabel = NULL;
+
 /* key that is currently hilighted */
 static GokKey* m_pKeyHighlighted;
 
@@ -82,6 +86,7 @@ GokFeedback* gok_feedback_new ()
     pNewFeedback->pNameSound = NULL;
     pNewFeedback->pNameSoundBackup = NULL;
     pNewFeedback->pFeedbackNext = NULL;
+    pNewFeedback->bSpeechOn = FALSE;
 
     return pNewFeedback;
 }
@@ -265,6 +270,14 @@ gboolean gok_feedback_open()
 
             g_free (key);
 
+            key = gok_feedback_get_key (feedback_name,
+                                        GOK_GCONF_FEEDBACK_SPEECH);
+            successful = gok_gconf_get_bool (gconf_client, key,
+                                             &(new_feedback->bSpeechOn));
+            g_free (key);
+            if (!successful)
+                return FALSE;
+
 			/* backup the feedback settings */
 			gok_feedback_backup (new_feedback);
 			
@@ -395,6 +408,17 @@ void gok_feedback_close()
             successful = gok_gconf_set_string (gconf_client, key,
                                                pFeedback->pNameSound);
             g_free (key);
+
+            /*
+             * Speech
+             */
+
+            key = gok_feedback_get_key (pFeedback->pName,
+                                        GOK_GCONF_FEEDBACK_SPEECH);
+            successful = gok_gconf_set_bool (gconf_client, key,
+                                             pFeedback->bSpeechOn);
+            g_free (key);
+
         }
         
         pFeedback = pFeedback->pFeedbackNext;
@@ -711,6 +735,7 @@ void gok_feedback_backup (GokFeedback* pFeedback)
 	pFeedback->bFlashOnBackup = pFeedback->bFlashOn;
 	pFeedback->NumberFlashesBackup = pFeedback->NumberFlashes;
 	pFeedback->bSoundOnBackup = pFeedback->bSoundOn;
+	pFeedback->bSpeechOnBackup = pFeedback->bSpeechOn;
 	
 	/* make this feedback not new */
 	pFeedback->bNewFeedback = FALSE;
@@ -818,6 +843,11 @@ gboolean gok_feedback_revert (GokFeedback* pFeedback)
 		pFeedback->bSoundOn = pFeedback->bSoundOnBackup;
 		bSettingsChanged = TRUE;
 	}
+	if (pFeedback->bSpeechOn != pFeedback->bSpeechOnBackup)
+	{
+		pFeedback->bSpeechOn = pFeedback->bSpeechOnBackup;
+		bSettingsChanged = TRUE;
+	}
 	if (pFeedback->NumberFlashes != pFeedback->NumberFlashesBackup)
 	{
 		pFeedback->NumberFlashes = pFeedback->NumberFlashesBackup;
@@ -879,6 +909,12 @@ gint gok_feedback_perform_effect (gchar* pNameFeedback)
 			{
 				gok_sound_play (pFeedback->pNameSound);				
 			}
+
+			/* FIXME: evil use of static string here */
+			if (pFeedback->bSpeechOn == TRUE && m_keyLabel)
+			{
+				gok_speech_speak (m_keyLabel);
+			}
 			
 			break;
 		}
@@ -1142,13 +1178,24 @@ GokKey* gok_feedback_get_highlighted_key()
 /**
 * gok_feedback_set_selected_key
 *
-* Accessor that returns a pointer to the selected key .
+* Sets the currently selected key.
 *
-* returns: A pointer to the currently selected key.
 **/
-void gok_feedback_set_selected_key (GokKey* pKey)
+void gok_feedback_set_selected_key (GokKey* key)
 {
-	m_pKeySelected = pKey;
+	/* 
+	 * odd logic here since selected key is set to NULL before speech output 
+	 * so we have to keep the old label around unless a new selected key has been set.
+	 */
+	if (key)
+	{
+		g_free (m_keyLabel);
+		if (key->pLabel && key->pLabel->Text)
+			m_keyLabel = g_strdup (key->pLabel->Text);
+		else
+			m_keyLabel = NULL;
+	}
+	m_pKeySelected = key;
 }
 
 /**
