@@ -39,8 +39,11 @@
 #define GOK_GCONF_DRIVE_COREPOINTER        "/apps/gok/drive_corepointer"
 #define GOK_GCONF_EXPAND                   "/apps/gok/expand"
 #define GOK_GCONF_USE_XKB_KBD              "/apps/gok/use_xkb_geom"
+#define GOK_GCONF_COMPOSE_KBD_TYPE         "/apps/gok/compose_kbd_type"
+#define GOK_GCONF_CUSTOM_COMPOSE_FILENAME  "/apps/gok/custom_compose_kbd"
 #define GOK_GCONF_DOCK_TYPE                "/apps/gok/dock_type"
 #define GOK_GCONF_KEYBOARD_DIRECTORY       "/apps/gok/keyboard_directory"
+#define GOK_GCONF_AUX_KEYBOARD_DIRECTORY   "/apps/gok/aux_keyboard_directory"
 #define GOK_GCONF_ACCESS_METHOD_DIRECTORY  "/apps/gok/access_method_directory"
 #define GOK_GCONF_DICTIONARY_DIRECTORY     "/apps/gok/dictionary_directory"
 #define GOK_GCONF_RESOURCE_DIRECTORY       "/apps/gok/resource_directory"
@@ -84,8 +87,11 @@
 #define GOK_GCONF_FEEDBACK_NUMBER_FLASHES  "number_flashes"
 #define GOK_GCONF_FEEDBACK_SOUND           "sound"
 #define GOK_GCONF_FEEDBACK_SOUNDNAME       "soundname"
+#define GOK_GCONF_FEEDBACK_SPEECH          "speech"
 
 #define GOK_GCONF_WORKAROUND_TEXT          "GConf seems to have problems accessing directories who do not have any siblings who are keys.  This key exists to ensure that the subdirectories in this directory do have a sibling who is a key - this key."
 
 #define GOK_GCONF_USE_AUX_DICTS            "/apps/gok/use_aux_dicts"
 #define GOK_GCONF_AUX_DICTS                "/apps/gok/aux_dictionaries"
+
+#define GOK_GCONF_VALUATOR_SENSITIVITY     "/apps/gok/valuator_sensitivity"
