@@ -801,6 +801,11 @@ gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode)
 		pKey->Type = KEYTYPE_BRANCHBACK;
 		pKey->Style = KEYSTYLE_BRANCHBACK;
 	}
+	else if (xmlStrcmp (pStringAttributeValue, (const xmlChar *) "branchCompose") == 0)
+	{
+		pKey->Type = KEYTYPE_BRANCHCOMPOSE;
+		pKey->Style = KEYSTYLE_BRANCH;
+	}
 	else if (xmlStrcmp (pStringAttributeValue, (const xmlChar *)"branchAlphabet") == 0)
 	{
 		pKey->Type = KEYTYPE_BRANCHALPHABET;
@@ -823,7 +828,7 @@ gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode)
 	}
 	else if (xmlStrcmp (pStringAttributeValue, (const xmlChar *)"branchEditText") == 0)
 	{
-		pKey->Type = KEYTYPE_BRANCHCOMPOSE;
+		pKey->Type = KEYTYPE_BRANCHEDIT;
 		pKey->Style = KEYSTYLE_GENERALDYNAMIC;
 	}
 	else if (xmlStrcmp (pStringAttributeValue, (const xmlChar *)"branchSettings") == 0)
@@ -904,6 +909,21 @@ gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode)
 		pKey->Style = KEYSTYLE_NORMAL;
 		gok_compose_key_init (pKey, pNode);
 	}
+	else if (xmlStrcmp (pStringAttributeValue, (const xmlChar *)"valuator") == 0)
+	{
+		pKey->Type = KEYTYPE_VALUATOR;
+		pKey->Style = KEYSTYLE_NORMAL;
+		pKey->is_repeatable = TRUE;
+		pKey->pGeneral = g_new0 (GokKeyboardValueOp, 1);
+		pStringSubAttributeValue = 
+			xmlGetProp (pNode, (const xmlChar *) "command");
+		if (pStringSubAttributeValue != NULL) 
+		{
+			* (GokKeyboardValueOp *) pKey->pGeneral = 
+				gok_keyboard_parse_value_op (pStringSubAttributeValue);
+			g_free (pStringSubAttributeValue);
+		}
+	}
 	else if (xmlStrcmp (pStringAttributeValue, (const xmlChar *)"select") == 0)
 	{
 		pKey->Type = KEYTYPE_SELECT;
@@ -1527,7 +1547,7 @@ gchar* gok_key_get_label (GokKey* pKey)
 	gchar buffer[150];
 	GokKeyLabel* pKeyLabel;
 	gboolean bFoundLabel;
-	int  type, keycode;
+	int  type = XkbAlphabeticIndex, keycode;
 	guint level;
 	guint group = gok_key_get_effective_group ();
 	guint mods = gok_spy_get_modmask ();
@@ -1544,8 +1564,8 @@ gchar* gok_key_get_label (GokKey* pKey)
 	    case OUTPUT_KEYCODE:
 	    case OUTPUT_KEYSYM:
 		keycode = gok_output_get_keycode (pKey->pOutput);
-		type = gok_key_get_xkb_type_index (xkb, keycode, group);
-		
+		if (keycode > 0)
+		    type = gok_key_get_xkb_type_index (xkb, keycode, group);
 #ifdef GOK_DEBUG
 		fprintf (stderr, "keycode %d, group %d, type=%d [%s]\n", keycode, group, type, typename);
 #endif
@@ -1559,9 +1579,8 @@ gchar* gok_key_get_label (GokKey* pKey)
 #endif
 		break;
 	    case OUTPUT_KEYSTRING:
-		level = gok_key_level_for_type (gok_keyboard_get_display (), xkb, XkbAlphabeticIndex, &mods);
-		break;
 	    default:
+		level = gok_key_level_for_type (gok_keyboard_get_display (), xkb, XkbAlphabeticIndex, &mods);
 		break;
 	}
 		
@@ -1596,7 +1615,8 @@ gchar* gok_key_get_label (GokKey* pKey)
 	{
 		if (pKeyLabel->level == level && pKeyLabel->group == group) 
 		{
-			return pKeyLabel->Text;
+			pTextReturned = pKeyLabel->Text;
+			break;
 		}
 		pKeyLabel = pKeyLabel->pLabelNext;
 	}
@@ -1877,7 +1897,7 @@ int gok_key_calculate_font_size (GokKey* pKey, gboolean bWidth, gboolean bHeight
 	if (bWidth == TRUE)
 	{
 		/* get the size of a key cell*/
-	        widthCell = gok_data_get_key_width () * 
+	        widthCell = gok_keyboard_get_cell_width (gok_main_get_current_keyboard ()) * 
 		        (pKey->Right - pKey->Left) - 2 * 
 		        gok_key_get_default_border_width (pKey) - 1;
 	
@@ -2158,6 +2178,7 @@ int gok_key_get_label_lengthpercell (GokKey* pKey)
 		return 0;
 	
 	numCells = pKey->Right - pKey->Left;
+	if (numCells <= 0) return 10;
 	return gok_key_get_label_length (pKey) / numCells;
 }
 
@@ -2411,15 +2432,16 @@ gok_key_wordcomplete_output (GokKey *pKey, GokWordComplete *complete)
 	{
 		return NULL;
 	}
-	
+
+	if (last_wordcomplete_output) {
+	    gok_output_delete_all (last_wordcomplete_output);
+	    last_wordcomplete_output = NULL;
+	}
+
 	if (word_part && (g_utf8_strlen (word_part, -1) < g_utf8_strlen (LabelText, -1)))
 	{
 		gchar *cp, *word_part_canonical;
 
-		if (last_wordcomplete_output) {
-		    gok_output_delete_all (last_wordcomplete_output);
-		    last_wordcomplete_output = NULL;
-		}
 		word_part_canonical = g_utf8_normalize (word_part, -1, G_NORMALIZE_DEFAULT);
 		cp = strstr (LabelText, word_part_canonical); 
 		/* sanity check: is our word_part found in our label? */
