@@ -58,6 +58,7 @@ KEYTYPE_BRANCHGUISELECTION,
 KEYTYPE_BRANCHGUISELECTACTION,
 KEYTYPE_PAGESELECTION,
 KEYTYPE_BRANCHCOMPOSE,
+KEYTYPE_BRANCHEDIT,
 KEYTYPE_TEXTNAV,
 KEYTYPE_EDIT,
 KEYTYPE_SELECT,
@@ -73,6 +74,7 @@ KEYTYPE_POINTERCONTROL,
 KEYTYPE_BRANCHHYPERTEXT,
 KEYTYPE_BRANCHTEXT,
 KEYTYPE_HYPERLINK,
+KEYTYPE_VALUATOR,
 KEYTYPE_HELP,
 KEYTYPE_ABOUT,
 KEYTYPE_DOCK,
