@@ -84,8 +84,8 @@ gok_keyslotter_on (gboolean bOnOff, int keytype)
 			}
 			else /* remove the slot keys from the keyboard */
 			{
-				if (((keytype = KEYTYPE_WORDCOMPLETE) && (gok_keyboard_get_wordcomplete_keys_added (pKeyboard) == TRUE)) ||
-				    ((keytype = KEYTYPE_COMMANDPREDICT) && (gok_keyboard_get_commandpredict_keys_added (pKeyboard) == TRUE)) )
+				if (((keytype == KEYTYPE_WORDCOMPLETE) && (gok_keyboard_get_wordcomplete_keys_added (pKeyboard) == TRUE)) ||
+				    ((keytype == KEYTYPE_COMMANDPREDICT) && (gok_keyboard_get_commandpredict_keys_added (pKeyboard) == TRUE)) )
 				{
 					pKey = pKeyboard->pKeyFirst;
 					while (pKey != NULL)
@@ -150,8 +150,8 @@ void gok_keyslotter_change_number_predictions (int Number, int keytype)
 	g_assert (pKeyboard != NULL);
 	while (pKeyboard != NULL)
 	{
-		if ( ((keytype = KEYTYPE_WORDCOMPLETE) &&( gok_keyboard_get_supports_wordcomplete (pKeyboard) == TRUE)) ||
-		     ((keytype = KEYTYPE_COMMANDPREDICT) &&( gok_keyboard_get_supports_commandprediction (pKeyboard) == TRUE) ))
+		if ( ((keytype == KEYTYPE_WORDCOMPLETE) &&( gok_keyboard_get_supports_wordcomplete (pKeyboard) == TRUE)) ||
+		     ((keytype == KEYTYPE_COMMANDPREDICT) &&( gok_keyboard_get_supports_commandprediction (pKeyboard) == TRUE) ))
 		{
 			/* remove all the word completion keys from the keyboard */
 			pKey = pKeyboard->pKeyFirst;
