@@ -44,7 +44,7 @@ typedef enum {
 typedef struct GokOutput{
 	gint Type;
 	AccessibleKeySynthType Flag;
-	const gchar* Name;
+	gchar* Name;
 	struct GokOutput* pOutputNext;	
 } GokOutput;
 
