@@ -24,16 +24,13 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <glade/glade.h>
 #include "gok-page-actions.h"
 #include "gok-action.h"
 #include "gok-input.h"
 #include "gok-log.h"
-#include "support.h"
 #include "gok-settings-dialog.h"
 
-/* pointer to the settings dialog window */
-static GtkWidget* m_pWindowSettings;
-
 /* action that is currently displayed */
 static GokAction* m_pActionCurrent;
 
@@ -56,23 +53,22 @@ static gboolean m_bChanged;
 *
 * returns: TRUE if the page was properly initialized, FALSE if not.
 **/
-gboolean gok_page_actions_initialize (GtkWidget* pWindowSettings)
+gboolean gok_page_actions_initialize (GladeXML* xml)
 {
-	GtkWidget* pComboBox;
+	GtkWidget* pComboBox, *range;
 	GokAction* pAction;
 	GList* items = NULL;
 	GSList* pDevice = NULL;
 	GSList* slist;
 	gboolean bReturnCode = TRUE; /* unused? */
 	
-	g_assert (pWindowSettings != NULL);
-	m_pWindowSettings = pWindowSettings;
+	g_assert (xml != NULL);
 	m_pActionCurrent = gok_action_get_first_action ();
 	m_bIgnoreChangeName = FALSE;
 	m_bChanged = TRUE;
 
 	/* add all the actions to the combo box */
-	pComboBox = lookup_widget (gok_settingsdialog_get_window(), "comboActionNames");
+	pComboBox = glade_xml_get_widget (xml, "comboActionNames");
 	g_assert (pComboBox != NULL);
 	
 	gok_page_actions_fill_combo_action_names();
@@ -80,7 +76,7 @@ gboolean gok_page_actions_initialize (GtkWidget* pWindowSettings)
 	gok_page_actions_update_controls (gok_action_get_first_action ());
 
 	/* initialize the XInput device combobox */
-	pComboBox = lookup_widget (gok_settingsdialog_get_window(), "comboInputDevice");
+	pComboBox = glade_xml_get_widget (xml, "comboInputDevice");
 	g_assert (pComboBox != NULL);
 	
 	pDevice = gok_input_get_device_list ();
@@ -120,7 +116,13 @@ gboolean gok_page_actions_initialize (GtkWidget* pWindowSettings)
 	}
 
 	gok_page_actions_enable_radios_type (FALSE);
-	
+
+	/* init the (now-global) valuator sensitivity slider */
+	range = glade_xml_get_widget (xml, "ValuatorSensitivityScale");
+	g_assert (range != NULL);
+	gtk_range_set_value (GTK_RANGE (range), 
+			     gok_data_get_valuator_sensitivity ());
+
 	return bReturnCode;
 }
 
@@ -255,7 +257,8 @@ void gok_page_actions_toggle_type_switch (gboolean Pressed)
 
 	g_assert (m_pActionCurrent != NULL);
 
-	pNotebook = (GtkNotebook*)lookup_widget (gok_settingsdialog_get_window(), "action_type_notebook");
+	pNotebook = (GtkNotebook*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
+			"action_type_notebook");
 	g_assert (pNotebook != NULL);
 	gtk_notebook_set_current_page (pNotebook, (Pressed) ? 0 : 1);
 
@@ -265,7 +268,8 @@ void gok_page_actions_toggle_type_switch (gboolean Pressed)
 	m_pActionCurrent->Type = ACTION_TYPE_SWITCH;
 	/* TODO: fix to allow MOUSEBUTTON also */
 
-	pRadioButton = (GtkToggleButton*)lookup_widget (gok_settingsdialog_get_window(), "radiobuttonSwitch1");
+	pRadioButton = (GtkToggleButton*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
+			"radiobuttonSwitch1");
 	g_assert (pRadioButton != NULL);
 	if (gtk_toggle_button_get_active (pRadioButton) == TRUE)
 	{
@@ -273,7 +277,8 @@ void gok_page_actions_toggle_type_switch (gboolean Pressed)
 	}
 	else
 	{
-		pRadioButton = (GtkToggleButton*)lookup_widget (gok_settingsdialog_get_window(), "radiobuttonSwitch2");
+		pRadioButton = (GtkToggleButton*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
+				"radiobuttonSwitch2");
 		g_assert (pRadioButton != NULL);
 		if (gtk_toggle_button_get_active (pRadioButton) == TRUE)
 		{
@@ -281,7 +286,8 @@ void gok_page_actions_toggle_type_switch (gboolean Pressed)
 		}
 		else
 		{
-			pRadioButton = (GtkToggleButton*)lookup_widget (gok_settingsdialog_get_window(), "radiobuttonSwitch3");
+			pRadioButton = (GtkToggleButton*) glade_xml_get_widget (
+					gok_settingsdialog_get_xml(), "radiobuttonSwitch3");
 			g_assert (pRadioButton != NULL);
 			if (gtk_toggle_button_get_active (pRadioButton) == TRUE)
 			{
@@ -289,7 +295,8 @@ void gok_page_actions_toggle_type_switch (gboolean Pressed)
 			}
 			else
 			{
-				pRadioButton = (GtkToggleButton*)lookup_widget (gok_settingsdialog_get_window(), "radiobuttonSwitch4");
+				pRadioButton = (GtkToggleButton*) glade_xml_get_widget (
+						gok_settingsdialog_get_xml(), "radiobuttonSwitch4");
 				g_assert (pRadioButton != NULL);
 				if (gtk_toggle_button_get_active (pRadioButton) == TRUE)
 				{
@@ -303,7 +310,8 @@ void gok_page_actions_toggle_type_switch (gboolean Pressed)
 		}
 	}
 
-	pRadioButton = (GtkToggleButton*)lookup_widget (gok_settingsdialog_get_window(), "radiobuttonPress");
+	pRadioButton = (GtkToggleButton*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
+			"radiobuttonPress");
 	g_assert (pRadioButton != NULL);
 	if (gtk_toggle_button_get_active (pRadioButton) == TRUE)
 	{
@@ -314,7 +322,8 @@ void gok_page_actions_toggle_type_switch (gboolean Pressed)
 		m_pActionCurrent->State = ACTION_STATE_RELEASE;
 	}
 
-	pSpinButton = (GtkSpinButton*)lookup_widget (gok_settingsdialog_get_window(), "spinDelay");
+	pSpinButton = (GtkSpinButton*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
+			"spinDelay");
 	g_assert (pSpinButton != NULL);
 	m_pActionCurrent->Rate = gtk_spin_button_get_value_as_int (pSpinButton);
 	}
@@ -331,7 +340,6 @@ void gok_page_actions_toggle_type_switch (gboolean Pressed)
 **/
 void gok_page_actions_toggle_type_valuator (gboolean Pressed)
 {
-	GtkToggleButton* pRadioButton;
 	GtkSpinButton* pSpinButton;
 
 	g_assert (m_pActionCurrent != NULL);
@@ -341,7 +349,8 @@ void gok_page_actions_toggle_type_valuator (gboolean Pressed)
 	  /* update the action from the controls */
 	  m_pActionCurrent->Type = ACTION_TYPE_DWELL;
 	}	
-	pSpinButton = (GtkSpinButton*)lookup_widget (gok_settingsdialog_get_window(), "pointer_delay_spinbutton");
+	pSpinButton = (GtkSpinButton*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
+			"pointer_delay_spinbutton");
 	g_assert (pSpinButton != NULL);
 	m_pActionCurrent->Rate = gtk_spin_button_get_value_as_int (pSpinButton);
 
@@ -544,7 +553,7 @@ void gok_page_actions_button_clicked_delete ()
 	GokAction* pAction;
 	GokAction* pActionDisplayed;
 	
-	pComboEntry = lookup_widget (gok_settingsdialog_get_window(), "entryActionName");
+	pComboEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entryActionName");
 	g_assert (pComboEntry != NULL);
 	pNameAction = gtk_entry_get_text (GTK_ENTRY(pComboEntry));
 
@@ -616,7 +625,7 @@ void gok_page_actions_fill_combo_action_names ()
 	m_bIgnoreChangeName = TRUE;
 	
 	/* find the combo box */
-	pComboBox = lookup_widget (gok_settingsdialog_get_window(), "comboActionNames");
+	pComboBox = glade_xml_get_widget (gok_settingsdialog_get_xml(), "comboActionNames");
 	g_assert (pComboBox != NULL);
 
 	/* create a list of action display names */
@@ -649,7 +658,7 @@ void gok_page_actions_fill_combo_action_names ()
 	{
 		pActionName = "";
 	}
-	pEntry = lookup_widget (gok_settingsdialog_get_window(), "entryActionName");
+	pEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entryActionName");
 	g_assert (pEntry != NULL);
 	gtk_entry_set_text (GTK_ENTRY(pEntry), pActionName);
 	
@@ -765,12 +774,12 @@ void gok_page_actions_update_controls (GokAction* pAction)
 	if (pAction->bPermanent == TRUE)
 	{
 		/* don't allow user to edit the action name */
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonChangeName");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonChangeName");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 			
 		gok_page_actions_enable_radios_type (FALSE);
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonDeleteAction");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonDeleteAction");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 	}
@@ -779,12 +788,12 @@ void gok_page_actions_update_controls (GokAction* pAction)
 		/* not permanent, enable controls for changing action type */
 		gok_page_actions_enable_radios_type (TRUE);
 						
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonDeleteAction");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonDeleteAction");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, TRUE);
 						
 		/* allow user to edit the action name */
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonChangeName");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonChangeName");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, TRUE);
 	}
@@ -793,35 +802,35 @@ void gok_page_actions_update_controls (GokAction* pAction)
 	switch (pAction->Number)
 	{
 		case 1:
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonSwitch1");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonSwitch1");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
 
 			break;
 	
 		case 2:
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonSwitch2");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonSwitch2");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
 
 			break;
 	
 		case 3:
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonSwitch3");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonSwitch3");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
 
 			break;
 	
 		case 4:
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonSwitch4");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonSwitch4");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
 
 			break;
 	
 		case 5:
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonSwitch5");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonSwitch5");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
 
@@ -834,13 +843,13 @@ void gok_page_actions_update_controls (GokAction* pAction)
 	switch (pAction->State)
 	{
 		case ACTION_STATE_PRESS:
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonPress");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonPress");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
 			break;
 			
 		case ACTION_STATE_RELEASE:
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonRelease");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonRelease");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
 			break;
@@ -850,15 +859,15 @@ void gok_page_actions_update_controls (GokAction* pAction)
 			break;
 	}
 	
-	pSpinControl = lookup_widget (gok_settingsdialog_get_window(), "spinDelay");
+	pSpinControl = glade_xml_get_widget (gok_settingsdialog_get_xml(), "spinDelay");
 	g_assert (pSpinControl != NULL);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpinControl), pAction->Rate);
 
-	pSpinControl = lookup_widget (gok_settingsdialog_get_window(), "pointer_delay_spinbutton");
+	pSpinControl = glade_xml_get_widget (gok_settingsdialog_get_xml(), "pointer_delay_spinbutton");
 	g_assert (pSpinControl != NULL);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpinControl), pAction->Rate);
 	
-	pCheckbox = lookup_widget (gok_settingsdialog_get_window(), "checkKeyAverage");
+	pCheckbox = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkKeyAverage");
 	g_assert (pSpinControl != NULL);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pCheckbox), pAction->bKeyAveraging);
 
@@ -869,7 +878,7 @@ void gok_page_actions_update_controls (GokAction* pAction)
 		case ACTION_TYPE_MOUSEBUTTON:
 		case ACTION_TYPE_KEY:
 			/* enable/disable the controls for switch actions */
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonTypeSwitch");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonTypeSwitch");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
 			gok_page_actions_enable_switch_controls (TRUE);
@@ -877,21 +886,21 @@ void gok_page_actions_update_controls (GokAction* pAction)
 			break;
 							
 		case ACTION_TYPE_DWELL:
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonTypeValuator");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonTypeValuator");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
 							
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window (), "activate_on_dwell_button");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "activate_on_dwell_button");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
 			gok_page_actions_enable_switch_controls (FALSE);
 			gok_page_actions_enable_valuator_controls (TRUE);
 			break;
 		case ACTION_TYPE_MOUSEPOINTER:
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonTypeValuator");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonTypeValuator");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
-			pRadioButton = lookup_widget (gok_settingsdialog_get_window (), "activate_on_enter_button");
+			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "activate_on_enter_button");
 			g_assert (pRadioButton != NULL);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
 							
@@ -903,7 +912,7 @@ void gok_page_actions_update_controls (GokAction* pAction)
 			gok_log_x ("default hit!\n");
 			break;
 	}
-	pRadioButton = lookup_widget (gok_settingsdialog_get_window(), "xinput_device_button");
+	pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "xinput_device_button");
 	g_assert (pRadioButton != NULL);
 	switch (pAction->Type)
 	{
@@ -930,14 +939,14 @@ void gok_page_actions_enable_switch_controls (gboolean bTrueFalse)
 {
 	GtkWidget* pFrame, *pNotebook;
 
-	pFrame = lookup_widget (gok_settingsdialog_get_window(), "frameSwitch");
+	pFrame = glade_xml_get_widget (gok_settingsdialog_get_xml(), "frameSwitch");
 	g_assert (pFrame != NULL);
 	
 	gtk_widget_set_sensitive (pFrame, bTrueFalse);
 	
 	if (bTrueFalse) 
 	{
-		pNotebook = lookup_widget (gok_settingsdialog_get_window(), "action_type_notebook");
+		pNotebook = glade_xml_get_widget (gok_settingsdialog_get_xml(), "action_type_notebook");
 		g_assert (pNotebook != NULL);
 		
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (pNotebook), 0);
@@ -954,14 +963,14 @@ void gok_page_actions_enable_valuator_controls (gboolean bTrueFalse)
 {
 	GtkWidget* pFrame, *pNotebook;
 
-	pFrame = lookup_widget (gok_settingsdialog_get_window(), "frameSwitch");
+	pFrame = glade_xml_get_widget (gok_settingsdialog_get_xml(), "frameSwitch");
 	g_assert (pFrame != NULL);
 	
 	gtk_widget_set_sensitive (pFrame, bTrueFalse);
 
 	if (bTrueFalse)
 	{
-		pNotebook = lookup_widget (gok_settingsdialog_get_window(), "action_type_notebook");
+		pNotebook = glade_xml_get_widget (gok_settingsdialog_get_xml(), "action_type_notebook");
 		g_assert (pNotebook != NULL);
 		
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (pNotebook), 1);
@@ -978,15 +987,15 @@ void gok_page_actions_enable_radios_type (gboolean bTrueFalse)
 {
 	GtkWidget* pWidget;
 
-	pWidget = lookup_widget (gok_settingsdialog_get_window(), "labelActionName");
+	pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "labelActionName");
 	g_assert (pWidget != NULL);
 	gtk_widget_set_sensitive (pWidget, bTrueFalse);
 	
-	pWidget = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonTypeSwitch");
+	pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonTypeSwitch");
 	g_assert (pWidget != NULL);
 	gtk_widget_set_sensitive (pWidget, bTrueFalse);
 	
-	pWidget = lookup_widget (gok_settingsdialog_get_window(), "radiobuttonTypeValuator");
+	pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonTypeValuator");
 	g_assert (pWidget != NULL);
 	gtk_widget_set_sensitive (pWidget, bTrueFalse);
 	
