@@ -24,6 +24,7 @@
 #endif
 
 #include <dirent.h>
+#include <locale.h>
 #include <gconf/gconf-client.h>
 #include "gok-scanner.h"
 #include "gok-data.h"
@@ -121,13 +122,13 @@ static GokScannerEffect* m_pEffectsOnDwell;
 #define MAX_HANDLERS 30
 
 /* number of possible calls */
-#define MAX_CALL_NAMES 61
+#define MAX_CALL_NAMES 62
 
 /* names of all the possible effect calls */
 /* This must be in the same order as the enum "CallIds" */
 static gchar ArrayCallNames[MAX_CALL_NAMES][24] ={
-"ChunkerReset", "ChunkerChunkNone", "ChunkerChunkRows", 
-"ChunkerChunkColumns", 
+"ChunkerReset", "ChunkerChunkNone", "ChunkerChunkKeys", 
+"ChunkerChunkRows", "ChunkerChunkColumns", 
 "ChunkerNextChunk", "ChunkerPreviousChunk", 
 "ChunkerNextKey", "ChunkerPreviousKey", 
 "ChunkerKeyUp", 
@@ -169,8 +170,13 @@ xmlChar *
 gok_scanner_get_lang (void)
 {
 	if (!gok_lang) {
-		gchar *lang = setlocale (LC_MESSAGES, NULL);
+		gchar *lang;
 		gchar **strings = NULL;
+#if HAVE_LC_MESSAGES
+		lang = setlocale (LC_MESSAGES, NULL);
+#else
+		lang = NULL;
+#endif
 		/* strip suffixes, etc. */
 		if (lang) 
 			strings = g_strsplit (lang, ".", 2);
@@ -214,7 +220,12 @@ gok_scanner_find_node (xmlNode *pNode, const xmlChar* name, const xmlChar* targe
 	xmlNode *retval = NULL;
 	int      target_lang_len = strlen ((char *)target_lang);
 	gboolean lang_is_matched = FALSE;	
+	gboolean is_lang_match;
+	gboolean is_perfect_match;
 
+	gok_log_enter();
+	is_lang_match = FALSE;
+	is_perfect_match = FALSE;
 	/* loop through the document looking for the name string */
 	while (pNode != NULL)
 	{
@@ -222,8 +233,6 @@ gok_scanner_find_node (xmlNode *pNode, const xmlChar* name, const xmlChar* targe
 		if (xmlStrcmp (pNode->name, name) == 0)
 		{
 			xmlChar *lang = NULL;
-			gboolean is_lang_match = FALSE;
-			gboolean is_perfect_match = FALSE;
 			/* If xml:lang matches our locale, return, else keep looking... */
 			lang = xmlNodeGetLang (pNode);
 			if (lang) {
@@ -234,6 +243,8 @@ gok_scanner_find_node (xmlNode *pNode, const xmlChar* name, const xmlChar* targe
 				retval = pNode;
 				if (!xmlStrncmp (lang, target_lang, target_lang_len)) { /* perfect match */
 					if (lang && node_lang) *node_lang = lang;
+					gok_log ("found node");
+					gok_log_leave();
 					return retval;
 				}
 				else if (is_lang_match) {
@@ -251,6 +262,7 @@ gok_scanner_find_node (xmlNode *pNode, const xmlChar* name, const xmlChar* targe
 		pNode = pNode->next;
 	}
 
+	gok_log_leave();
 	return retval;
 }
 
@@ -518,16 +530,16 @@ gboolean gok_scanner_read_access_method (gchar* Filename)
 	strcpy (pAccessMethod->DisplayName, (gchar *)pStringAttributeValue);
 
 	/* read the UI for the access method */
-	gok_scanner_read_description (pDoc, pNodeRoot->xmlChildrenNode, pAccessMethod);
-	gok_scanner_read_operation (pDoc, pNodeRoot->xmlChildrenNode, pAccessMethod);
-	gok_scanner_read_feedback (pDoc, pNodeRoot->xmlChildrenNode, pAccessMethod);
-	gok_scanner_read_options (pDoc, pNodeRoot->xmlChildrenNode, pAccessMethod);
+	gok_scanner_read_description (pDoc, pNodeAccessmethod->xmlChildrenNode, pAccessMethod);
+	gok_scanner_read_operation (pDoc, pNodeAccessmethod->xmlChildrenNode, pAccessMethod);
+	gok_scanner_read_feedback (pDoc, pNodeAccessmethod->xmlChildrenNode, pAccessMethod);
+	gok_scanner_read_options (pDoc, pNodeAccessmethod->xmlChildrenNode, pAccessMethod);
 
 	/* read the rates for this effect */
-	gok_scanner_read_rates (pNodeRoot->xmlChildrenNode, pAccessMethod);
+	gok_scanner_read_rates (pNodeAccessmethod->xmlChildrenNode, pAccessMethod);
 
 	/* read the initializing effects for this access method */
-	pNodeInitialization = gok_keyboard_find_node (pNodeRoot, "initialization");
+	pNodeInitialization = gok_keyboard_find_node (pNodeAccessmethod, "initialization");
 	if (pNodeInitialization != NULL)
 	{
 		pAccessMethod->pInitializationEffects = gok_scanner_read_effects (pNodeInitialization, pAccessMethod);
@@ -536,7 +548,7 @@ gboolean gok_scanner_read_access_method (gchar* Filename)
 	pStateLast = NULL;
 
 	/* get all the handler states */
-	pNodeState = gok_keyboard_find_node (pNodeRoot, "state");
+	pNodeState = gok_keyboard_find_node (pNodeAccessmethod, "state");
 	while (pNodeState != NULL)
 	{
 		/* is this a state? */
@@ -967,6 +979,7 @@ gboolean gok_scanner_read_description (xmlDoc* pDoc, xmlNode* pNode, GokAccessMe
 		return TRUE;
 	}
 	else {
+		strncpy (pAccessMethod->Description, (gchar *)"error reading description", MAX_DESCRIPTION_TEXT);
 		gok_log_leave();
 		return FALSE;
 	}
@@ -2136,6 +2149,7 @@ void gok_scanner_on_key_enter (GokKey* pKey)
 {
 	m_pKeyEntered = pKey;
 
+	gok_main_raise_window ();
 	gok_scanner_timer_start_dwell();
 		
 	gok_scanner_perform_effects (m_pEffectsOnKeyEnter);
@@ -2405,6 +2419,7 @@ gboolean gok_scanner_on_timer5 (gpointer data)
 **/
 void gok_scanner_on_switch1_down ()
 {
+	gok_main_raise_window ();
 	gok_scanner_perform_effects (m_pEffectsOnSwitch1Down);
 }
 
@@ -2425,6 +2440,7 @@ void gok_scanner_on_switch1_up ()
 **/
 void gok_scanner_on_switch2_down ()
 {
+	gok_main_raise_window ();
 	gok_scanner_perform_effects (m_pEffectsOnSwitch2Down);
 }
 
@@ -2445,6 +2461,7 @@ void gok_scanner_on_switch2_up ()
 **/
 void gok_scanner_on_switch3_down ()
 {
+	gok_main_raise_window ();
 	gok_scanner_perform_effects (m_pEffectsOnSwitch3Down);
 }
 
@@ -2465,6 +2482,7 @@ void gok_scanner_on_switch3_up ()
 **/
 void gok_scanner_on_switch4_down ()
 {
+	gok_main_raise_window ();
 	gok_scanner_perform_effects (m_pEffectsOnSwitch4Down);
 }
 
@@ -2485,6 +2503,7 @@ void gok_scanner_on_switch4_up ()
 **/
 void gok_scanner_on_switch5_down ()
 {
+	gok_main_raise_window ();
 	gok_scanner_perform_effects (m_pEffectsOnSwitch5Down);
 }
 
@@ -2532,6 +2551,26 @@ void gok_scanner_perform_effects (GokScannerEffect* pEffect)
 				EffectCodeReturned = gok_chunker_chunk_none ();
 				break;
 
+			case CALL_CHUNKER_CHUNK_KEYS:
+				if (gok_data_get_setting (pAccessMethod->Name, pEffect->CallParam1, 
+											&param1Rate, NULL) == TRUE)
+				{
+					if (gok_data_get_setting (pAccessMethod->Name, pEffect->CallParam2, 
+												&param2Rate, NULL) == TRUE)
+					{
+						EffectCodeReturned = gok_chunker_chunk_keys (param1Rate, param2Rate); 
+					}
+					else
+					{
+						gok_log_x ("Can't get CHUNKER_KEYS param2 setting: %s!\n", pEffect->pName);
+					}
+				}
+				else
+				{
+					gok_log_x ("Can't get CHUNKER_KEYS param1 setting: %s!\n", pEffect->pName);
+				}
+				break;
+
 			case CALL_CHUNKER_CHUNK_ROWS:
 				if (gok_data_get_setting (pAccessMethod->Name, pEffect->CallParam1, 
 											&param1Rate, NULL) == TRUE)
@@ -2633,51 +2672,19 @@ void gok_scanner_perform_effects (GokScannerEffect* pEffect)
 				break;
 
 			case CALL_CHUNKER_WRAP_TOBOTTOM:
-				if (gok_data_get_setting (pAccessMethod->Name, pEffect->pName, 
-											&rate, NULL) == TRUE)
-				{
-					gok_chunker_wraptobottom (rate); 
-				}
-				else
-				{
-					gok_log_x ("Can't get CHUNKER_WRAP_TOBOTTOM name setting: %s!\n", pEffect->pName);
-				}
+				gok_chunker_wraptobottom (rate); 
 				break;
 
 			case CALL_CHUNKER_WRAP_TOLEFT:
-				if (gok_data_get_setting (pAccessMethod->Name, pEffect->pName, 
-											&rate, NULL) == TRUE)
-				{
-					gok_chunker_wraptoleft (rate); 
-				}
-				else
-				{
-					gok_log_x ("Can't get CHUNKER_WRAP_TOLEFT name setting: %s!\n", pEffect->pName);
-				}
+				gok_chunker_wraptoleft (rate); 
 				break;
 
 			case CALL_CHUNKER_WRAP_TORIGHT:
-				if (gok_data_get_setting (pAccessMethod->Name, pEffect->pName, 
-											&rate, NULL) == TRUE)
-				{
-					gok_chunker_wraptoright (rate); 
-				}
-				else
-				{
-					gok_log_x ("Can't get CHUNKER_WRAP_TORIGHT name setting: %s!\n", pEffect->pName);
-				}
+				gok_chunker_wraptoright (rate);
 				break;
 
 			case CALL_CHUNKER_WRAP_TOTOP:
-				if (gok_data_get_setting (pAccessMethod->Name, pEffect->pName, 
-											&rate, NULL) == TRUE)
-				{
-					gok_chunker_wraptotop (rate); 
-				}
-				else
-				{
-					gok_log_x ("Can't get CHUNKER_WRAP_TOTOP name setting: %s!\n", pEffect->pName);
-				}
+				gok_chunker_wraptotop (rate); 
 				break;
 
 			case CALL_CHUNKER_MOVE_LEFTRIGHT:
@@ -2739,7 +2746,6 @@ gok_log_x ("chunker move topbottom\n");
 				break;
 
 			case CALL_CHUNKER_IF_KEY_SELECTED:
-gok_log_x ("chunker  if key selected\n");
 				EffectCodeReturned = gok_chunker_if_key_selected(); 
 				break;
 
@@ -3314,6 +3320,7 @@ gok_scanner_current_state_uses_corepointer (void)
 		gok_gconf_get_string (gconf_client_get_default (), 
 				      GOK_GCONF_INPUT_DEVICE, 
 				      &input_device_name);
+
 		if (input_device_name == NULL)
 			retval = TRUE;
 		else
@@ -3493,3 +3500,10 @@ gok_scanner_repeat_on(void)
 	}
 	gok_log_leave();
 }
+
+void
+gok_scanner_drop_refs (GokKey *pKey)
+{
+  if (m_pKeyEntered == pKey) m_pKeyEntered = NULL;
+  if (m_pContainingKey == pKey) m_pContainingKey = NULL;
+}
