@@ -254,7 +254,9 @@ void on_button_try (GtkButton* button, gpointer user_data)
 	/* if any settings have changed then refresh the keyboard */
 	if (bDataChanged == TRUE)
 	{
-		gok_main_display_scan_reset();		
+		gok_main_display_scan_reset();
+		/* and post a warning if the new settings use corepointer */
+		gok_main_warn_if_corepointer_mode (_("You appear to be configuring GOK to use \'core pointer\' mode."), FALSE);
 	}
 }
 
