@@ -138,7 +138,15 @@ static gboolean spyshutdown = FALSE;/* this global could be removed if we have a
 static void
 gok_spy_set_focussed_object (Accessible *accessible)
 {
+    if (currently_focussed_object) 
+    {
+	gok_spy_accessible_unref (currently_focussed_object);
+    }
     currently_focussed_object = accessible;
+    if (accessible) 
+    {
+	gok_spy_accessible_ref (accessible);
+    }
 }
 
 /*
@@ -949,6 +957,7 @@ AccessibleNode* gok_spy_refresh( AccessibleNode* plist)
 void gok_spy_free_nodes (GSList *nodes)
 {
 	GSList *nodelist = nodes;
+	gok_log_enter();
 	while (nodelist) 
 	{
 		AccessibleNode *node = nodelist->data;
@@ -962,6 +971,7 @@ void gok_spy_free_nodes (GSList *nodes)
 		nodelist = nodelist->next;
 	}
 	g_slist_free (nodes);
+	gok_log_leave();
 }
 
 /** 
