@@ -32,6 +32,8 @@
 #  include <config.h>
 #endif
 
+#include <locale.h>
+
 #include "gok-word-complete.h"
 #include "gok-keyslotter.h"
 #include "main.h"
@@ -42,6 +44,7 @@
 
 #include "word-complete.h" /* TODO: remove this when we make this class abstract */
 #include "gok-utf8-word-complete.h"
+#include "gok-sliding-window-word-complete.h"
 
 static void gok_wordcomplete_finalize (GObject *obj);
 static void gok_wordcomplete_real_reset (GokWordComplete *complete);
@@ -54,6 +57,9 @@ static gchar **gok_wordcomplete_real_predict (GokWordComplete *complete, gint nu
 static gchar *gok_wordcomplete_real_get_word_part (GokWordComplete *complete);
 static const gchar *  gok_wordcomplete_real_get_aux_dict (GokWordComplete *complete);
 static gboolean gok_wordcomplete_real_set_aux_dict (GokWordComplete *complete, gchar *dict_path);
+static const gchar *  gok_wordcomplete_real_get_delimiter (GokWordComplete *complete);
+
+static GokOutput OutputSpace;
 
 struct _GokWordCompletePrivate 
 {
@@ -95,6 +101,13 @@ gok_wordcomplete_class_init (GokWordCompleteClass *klass)
 	klass->get_word_part = gok_wordcomplete_real_get_word_part;
 	klass->set_aux_dictionary = gok_wordcomplete_real_set_aux_dict;
 	klass->get_aux_dictionary = gok_wordcomplete_real_get_aux_dict;
+	klass->get_delimiter = gok_wordcomplete_real_get_delimiter;
+
+	/* end the word with a 'space' */
+	OutputSpace.Type = OUTPUT_KEYSYM;
+	OutputSpace.Flag = SPI_KEY_PRESSRELEASE;
+	OutputSpace.Name = "space";
+	OutputSpace.pOutputNext = NULL;
 }
 
 static void
@@ -139,6 +152,23 @@ void gok_wordcomplete_close (GokWordComplete *complete)
 		(*klass->close) (complete);
 }
 
+/**
+* gok_wordcomplete_get_delimiter
+*
+* returns: a character string (usually one character long) that should be output after a word-completion 
+*          event, for example a space.  In some locales, this string may be empty or NULL.
+**/
+const gchar *
+gok_wordcomplete_get_delimiter (GokWordComplete *complete)
+{
+	GokWordCompleteClass *klass = GOK_WORDCOMPLETE_GET_CLASS (complete);
+
+	if (klass->get_delimiter)
+		return (*klass->get_delimiter) (complete);
+	else
+		return NULL;
+}
+
 /**
  * gok_wordcomplete_unichar_push:
  *
@@ -350,7 +380,16 @@ GokWordComplete*
 gok_wordcomplete_get_default (void)
 {
 	if (default_wordcomplete_engine == NULL)
+	{
+	    gchar *locale = setlocale (LC_MESSAGES, NULL);
+	    if (!strcmp (locale, "zh_CN") || 
+		!strcmp (locale, "zh_TW") || 
+		!strcmp (locale, "jp_JP") ||
+		!strcmp (locale, "jp"))
+		default_wordcomplete_engine = g_object_new (GOK_TYPE_SW_WORDCOMPLETE, NULL);  
+	    else
 		default_wordcomplete_engine = g_object_new (GOK_TYPE_UTF8WORDCOMPLETE, NULL);  
+	}
         /* TODO: establish default subtype and create type - making the base class abstract */
 	return default_wordcomplete_engine;
 }
@@ -524,6 +563,13 @@ gok_wordcomplete_last_combine (GokWordComplete *complete, gunichar combining_let
 }
 
 /* implementations of GokWordCompleteClass methods */
+
+static const gchar*
+gok_wordcomplete_real_get_delimiter (GokWordComplete *complete)
+{    
+	return " ";
+}
+
 static void 
 gok_wordcomplete_real_reset (GokWordComplete *complete)
 {
