@@ -23,6 +23,7 @@
 #define __GOKWORDCOMPLETE_H__
 
 #include <glib-object.h>
+#include "gok-output.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -78,6 +79,7 @@ struct _GokWordCompleteClass
 	gchar*    (* get_word_part) (GokWordComplete *complete);
         const gchar*    (* get_aux_dictionary) (GokWordComplete *complete);
 	gboolean  (* set_aux_dictionary) (GokWordComplete *complete, gchar *dict_path);
+	const gchar*    (* get_delimiter) (GokWordComplete *complete);
 };
 
 gboolean gok_wordcomplete_open           (GokWordComplete *complete, gchar *directory);
@@ -96,6 +98,7 @@ gchar**  gok_wordcomplete_process_and_predict (GokWordComplete *complete, const
 
 gchar*   gok_wordcomplete_get_word_part (GokWordComplete *complete);
 const gchar*   gok_wordcomplete_get_aux_dictionaries (GokWordComplete *complete);
+const gchar*   gok_wordcomplete_get_delimiter  (GokWordComplete *complete);
 gboolean gok_wordcomplete_set_aux_dictionaries (GokWordComplete *complete, gchar *dictionary_path);
 
 #ifdef __cplusplus
