@@ -140,6 +140,9 @@ static int bRememberGeometryOption = 0;
 static int bDisplaySettingsDialog = 0;
 static int bExtras = 0;
 
+static gint _screen_height, _screen_width;
+
+
 static struct poptOption options[] = {
 	{
 		"access-method", 
@@ -500,7 +503,7 @@ gok_main_open(gint argc, gchar *argv[])
 		gok_main_initialize_wordcomplete ();
 		gok_main_initialize_commandprediction ();
 	}
-	
+
 	/* create the settings dialog */
 	if (gok_settingsdialog_open (bDisplaySettingsDialog) == FALSE)
 	{
@@ -526,6 +529,7 @@ gok_main_open(gint argc, gchar *argv[])
 
 	if (!bLoginOption) {
 		gok_main_check_accessibility();
+		gok_main_warn_if_corepointer_mode (_("You are using GOK in \'core pointer\' mode."), FALSE);
 	}
 	
 	if (!gok_main_check_sticky_keys (m_pWindowMain)) {
@@ -726,8 +730,16 @@ void gok_main_window_change_listener (Accessible* pAccessible)
 		gok_chunker_chunk (pKeyboard);
 		pKeyboard->bRequiresChunking = FALSE;
 	
-		/* highlight the first chunk */
-		gok_chunker_highlight_first_chunk();
+		/* fixme?: this is a kludge workaround for direct scanning */
+		if (strcmp ("directed", gok_data_get_name_accessmethod()) == 0) {
+			gok_chunker_highlight_center_key();
+		}
+		else {
+			/* highlight the first chunk */
+			gok_chunker_highlight_first_chunk();
+		}
+		gok_chunker_select_chunk();
+		
 		
 		/* restart the scanning process */
 		gok_scanner_start();
@@ -1298,7 +1310,8 @@ gboolean gok_main_ds (GokKeyboard* pKeyboard)
 	/* layout the keys on the keyboard */
 	if (gok_keyboard_layout (pKeyboard, KEYBOARD_LAYOUT_NORMAL, 
 		 	/*KEYBOARD_SHAPE_WIDE KEYBOARD_SHAPE_SQUARE*/ 
-			KEYBOARD_SHAPE_KEYSQUARE, FALSE) == FALSE)
+			KEYBOARD_SHAPE_KEYSQUARE
+			, FALSE) == FALSE)
 	{
 		gok_log_leave();
 		return FALSE;
@@ -1348,7 +1361,10 @@ GtkWidget* gok_main_create_window (gboolean is_dock)
 	GtkWidget *fixed1;
 
 	gok_log_enter();
-						     
+					
+	_screen_height = gdk_screen_get_height (gdk_screen_get_default ());
+	_screen_width = gdk_screen_get_width (gdk_screen_get_default ());
+	     
 	window1 = g_object_connect (gtk_widget_new (gtk_window_get_type (),
 				"user_data", NULL,
 				"can_focus", FALSE,
@@ -1986,6 +2002,22 @@ gok_main_set_wm_dock (gboolean is_dock)
 
 }
 
+
+enum {
+	STRUT_LEFT = 0,
+	STRUT_RIGHT = 1,
+	STRUT_TOP = 2,
+	STRUT_BOTTOM = 3,
+	STRUT_LEFT_START = 4,
+	STRUT_LEFT_END = 5,
+	STRUT_RIGHT_START = 6,
+	STRUT_RIGHT_END = 7,
+	STRUT_TOP_START = 8,
+	STRUT_TOP_END = 9,
+	STRUT_BOTTOM_START = 10,
+	STRUT_BOTTOM_END = 11
+};
+
 /*
  * TODO: GtkDoc this!
  */
@@ -1994,16 +2026,19 @@ gok_main_update_struts (gint width, gint height)
 {
 	GtkWidget *widget = gok_main_get_main_window ();
 	Atom atom_strut = gdk_x11_get_xatom_by_name ("_NET_WM_STRUT");
-	guint32 struts[4];
+	Atom atom_strut_partial = gdk_x11_get_xatom_by_name ("_NET_WM_STRUT_PARTIAL");
+	guint32 struts[12] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 
 	switch (gok_data_get_dock_type ()) {
 	case GOK_DOCK_TOP:
-		struts[0] = struts[2] = struts[3] = 0;
-		struts[1] = height;
+		struts[STRUT_TOP] = height;
+		struts[STRUT_TOP_START] = 0;
+		struts[STRUT_TOP_END] = _screen_width - 1;
 		break;
 	case GOK_DOCK_BOTTOM:
-		struts[0] = struts[1] = struts[2]= 0;
-		struts[3] = height;
+		struts[STRUT_BOTTOM] = height;
+		struts[STRUT_BOTTOM_START] = 0;
+		struts[STRUT_BOTTOM_END] = _screen_width - 1;
 		break;
 	default:
 		return;
@@ -2012,11 +2047,18 @@ gok_main_update_struts (gint width, gint height)
 	gdk_error_trap_push ();
 	/* this means that we are responsible for placing ourselves appropriately on screen */
 	if (widget && widget->window)
+	{
 		XChangeProperty (GDK_WINDOW_XDISPLAY (widget->window), 
 				 GDK_WINDOW_XWINDOW (widget->window), 
 				 atom_strut,
 				 XA_CARDINAL, 32, PropModeReplace,
 				 (guchar *) &struts, 4);
+		XChangeProperty (GDK_WINDOW_XDISPLAY (widget->window), 
+				 GDK_WINDOW_XWINDOW (widget->window), 
+				 atom_strut_partial,
+				 XA_CARDINAL, 32, PropModeReplace,
+				 (guchar *) &struts, 12);
+	}
 	gdk_error_trap_pop ();
 }
 
@@ -2113,7 +2155,8 @@ gok_main_close()
 	/* note, call all closing functions that delete UI before calling gok_settingsdialog_close */
 	gok_scanner_close(); /* deletes UI */
 
-	/*	gok_settingsdialog_close(); */
+	/* gok_settingsdialog_close(); */
+	
 /**
  * the above, in context of the following calls,  is fundamentally broken, in that it 
  * destroys widgets which are either already destroyed, or are about to be destroyed below. 
@@ -2340,7 +2383,7 @@ gok_main_check_sticky_keys (GtkWidget *widget)
 				xkb_ok = TRUE;
 				if (!bLoginOption) {
 				  dialog = gtk_message_dialog_new (NULL,
-								 GTK_DIALOG_DESTROY_WITH_PARENT,
+								 0,
 								 GTK_MESSAGE_INFO,
 								 GTK_BUTTONS_OK,
 								 _("GOK has enabled Sticky Keys, which it requires.\n"));
@@ -2349,6 +2392,10 @@ gok_main_check_sticky_keys (GtkWidget *widget)
 				  g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
 							  G_CALLBACK (gtk_widget_destroy),
 							  GTK_OBJECT (dialog));
+
+				  /* reset hint to avoid self-occlusion */
+				  gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_NORMAL);
+				  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 				  gtk_widget_show_all (dialog);
 				}
 			}
@@ -2379,6 +2426,8 @@ gok_main_check_sticky_keys (GtkWidget *widget)
 
 static GtkWidget* acd = NULL; /* accessibility check dialog */
 
+static GtkWidget* _corepointer_warning = NULL; /* core pointer warning dialog */
+
 void check_accessibility_cb ( GObject* o, gpointer* data )
 {
 	GnomeClient *client;
@@ -2406,6 +2455,67 @@ void check_accessibility_cb ( GObject* o, gpointer* data )
 
 }
 
+void
+gok_main_help_cb (gpointer data) 
+{
+	GError *error = NULL;
+	gchar *helpuri = data;
+	/* TODO: detect error launching help, and give informative message */
+	gnome_help_display (helpuri, NULL, &error);
+}
+ 
+void
+gok_main_warn_if_corepointer_mode (gchar *message_prefix, gboolean always)
+{
+	if ((always && !_corepointer_warning) || gok_scanner_current_state_uses_corepointer ()) 
+	{
+		GtkWidget*	button;
+		gint         response_id;
+		gboolean 	returnCode = TRUE;
+		gchar *message = g_strconcat (message_prefix, "\n\n",
+			_("This means that the device you are using to operate GOK"
+			"\nis also controlling the system pointer (or \'mouse pointer\')."
+			"\nConflicts with applications\' use of the pointer may interfere"
+			"\nwith your ability to use applications or GOK.\n"
+			"\nWe strongly recommend configuring your input device as an"
+                        "\n\'Extended\' input device instead; see GOK Help for more information."), NULL);
+		
+		if (_corepointer_warning == NULL)
+		{
+			_corepointer_warning = gtk_message_dialog_new (
+				NULL, 
+				GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_MESSAGE_WARNING, 
+				GTK_BUTTONS_NONE,			
+				message);
+			g_free (message);
+			
+			button = gtk_button_new_from_stock(GTK_STOCK_HELP);
+			gtk_container_add (GTK_CONTAINER (GTK_DIALOG(_corepointer_warning)->action_area),
+					   button);
+			g_signal_connect_swapped (G_OBJECT (button), "clicked", 
+						  G_CALLBACK (gok_main_help_cb), "gok.xml");
+			
+			button = gtk_button_new_from_stock(GTK_STOCK_PREFERENCES);
+			gtk_container_add (GTK_CONTAINER (GTK_DIALOG(_corepointer_warning)->action_area),
+					   button);
+			g_signal_connect (G_OBJECT (button), "clicked", 
+					  G_CALLBACK (gok_settingsdialog_show), NULL);
+			
+			button = gtk_button_new_from_stock(GTK_STOCK_OK);
+			gtk_container_add (GTK_CONTAINER (GTK_DIALOG(_corepointer_warning)->action_area),
+					   button);
+			g_signal_connect_swapped (G_OBJECT (button), "clicked", 
+						  G_CALLBACK (gtk_widget_destroy), _corepointer_warning);
+			
+			/* reset hint to avoid self-occlusion */
+			gtk_window_set_type_hint (GTK_WINDOW (_corepointer_warning), GDK_WINDOW_TYPE_HINT_NORMAL);
+			gtk_window_set_position (GTK_WINDOW (_corepointer_warning), GTK_WIN_POS_CENTER);
+			gtk_widget_show_all (_corepointer_warning);
+		}
+	}
+}
+
 void
 gok_main_check_accessibility ()
 {
@@ -2425,7 +2535,7 @@ gok_main_check_accessibility ()
 		acd = gtk_message_dialog_new (
 			NULL, 
 			GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_MESSAGE_INFO, /* FIXME: GTK_MESSAGE_WARNING occludes keyboard */
+			GTK_MESSAGE_WARNING,
 			GTK_BUTTONS_NONE,			
 			_("Assistive Technology Support Is Not Enabled." 
 		"\n\n" 
@@ -2445,7 +2555,7 @@ gok_main_check_accessibility ()
 		"click " 
 		"Close" "." 
 		"\n\n"));
-		   
+
 		button = gtk_button_new_with_label(_("Enable and Log Out"));
 		gtk_container_add (GTK_CONTAINER (GTK_DIALOG(acd)->action_area),
 						  button);
@@ -2464,7 +2574,9 @@ gok_main_check_accessibility ()
 		g_signal_connect(G_OBJECT (button), "clicked", 
 			G_CALLBACK (check_accessibility_cb), (gpointer) "continue");
 						  
-
+		/* reset hint to avoid self-occlusion */
+		gtk_window_set_type_hint (GTK_WINDOW (acd), GDK_WINDOW_TYPE_HINT_NORMAL);
+		gtk_window_set_position (GTK_WINDOW (acd), GTK_WIN_POS_CENTER);
 		gtk_widget_show_all (acd);
 		
 	}
