@@ -585,7 +585,7 @@ WordCompletePredictString (GokWordComplete *complete, const gchar* pWord, gint n
 		}
 
 		/* add the prediction word to our buffer */
-		word_predict_list[i] = strdup (m_Predictions[highPriorityIndex].word);
+		word_predict_list[i] = g_strdup (m_Predictions[highPriorityIndex].word);
 		m_Predictions[highPriorityIndex].priority = 0;
 		bMadePrediction = TRUE;
 	}
